/**
 * 图表插件
 */
$.fn.chart = function(opt){
    var $this = $(this);
	
	this.init = function(){
        //获取区域长度
		this.width = $this.width();
		this.height = $this.height();
		
		//计算x,y轴等份数
		this.xnum = opt.labels.length;
		this.ynum = 5;
		
		//计算最大值,最小值
		this.max = this.min = 0;
		for(var i in opt.data){
		    for(var j in opt.data[i]){
			    if(opt.data[i][j] > this.max)this.max = opt.data[i][j];
			}
		}
		
		if(this.max == 0)this.max = 100;
		
		this.min = this.max;
		for(var i in opt.data){
		    for(var j in opt.data[i]){
			    if(opt.data[i][j] < this.min)this.min = opt.data[i][j];
			}
		}
		
		//计算比值
		var bv = (this.max % this.ynum) == 0 ? this.max / this.ynum : parseInt(this.max / this.ynum) + 1;
		var av = this.max > 1000 ? 10*this.ynum : 10;
		this.bv = bv % av == 0 ? bv : (parseInt(bv/av) + 1)*av;
		
		//设置x、y轴标签的所占长或高 ,以及图标的padding
		this.xswidth = 30;
		this.ysheight = 30;
		this.pwidth = 20;
		this.pheight = 30;
		
		//计算x,y轴每等份的长或高
		this.xwidth = (this.width - this.xswidth - this.pwidth) / this.xnum;
		this.yheight = (this.height - this.ysheight - this.pheight) / this.ynum;
		
		//渲染
		this.render();
	}
	
	this.render = function(){
	    var html = '<svg version="1.1" style="width:'+(this.width * 0.1)+'rem;height:'+this.height* 0.1+'rem;font-family\'Lucida Grande\', \'Lucida Sans Unicode\', Arial, Helvetica, sans-serif;font-size:12px;" xmlns="http://www.w3.org/2000/svg">';
					//<rect x="0" y="0" width="'+this.width+'" height="'+this.height+'" strokeWidth="0" fill="#FFFFFF"/>';
		html += this.getXline();			
		html += this.getYline();
        html += this.getXlabel();
		html += this.getYlabel();
		html += this.getLine(opt.data[0] , '#31c690');
		html += this.getLine(opt.data[1] , 'red');
		html += this.getPot(opt.data[0] , '#31c690');
		html += this.getPot(opt.data[1] , 'red');
		html += this.getalias();
		html  += '</svg>';
		$this.html(html);
	}

	this.getXline = function(){
	    var html = '<g>' , h = 0 , x = 0;
		//加标尺
		h = this.height - this.ysheight;
		for(var i = 0;i <= this.xnum;i++){
		    x = i * this.xwidth  + this.xswidth;
		    html += ('<path fill="none" d="M'+ x +' '+h+' L'+x+' '+(h + 5)+'" stroke="#ddd" stroke-width="1" visibility="visible"/>');
		}
		
		//整个x轴线
		h = this.height - this.ysheight;
		html += '<path fill="none" d="M'+ this.xswidth +' '+h+' L'+(this.width - this.pwidth)+' '+h+'" stroke="#ddd" stroke-width="1" visibility="visible"/>';
		html += '</g>';
		return html;
	}
	
	this.getYline = function(){
	    var html = '<g>' , h = 0;
		for(var i= 1;i <=  this.ynum ; i++){
		    h = this.height - this.ysheight - i *this.yheight;
		    html += ('<path fill="none" d="M'+ this.xswidth +' '+h+' L'+(this.width - this.pwidth)+' '+h+'" stroke="#ddd" stroke-width="1" visibility="visible"/>');
		}
		html += '</g>';
		return html;
	}
	
	this.getXlabel = function(){
	    var html = '<g>' , h = 0;
		h = this.height - this.ysheight;
		for(var i = 0;i < this.xnum;i++){
		    x = i * this.xwidth  + this.xswidth;
		    html += ('<text x="'+(x + this.xwidth/ 2)+'" y="'+(h + 15)+'" text-anchor="middle" style="width:'+this.xwidth*0.1+'rem;color:#999;cursor:default;font-size:1.1rem;fill:#999;" opacity="1">'+opt.labels[i]+'</text>');
		}
		html += '</g>';
		return html;
	}
	
	this.getYlabel = function(){
		//计算单位
		var label = '';
		if(this.bv > 100)label = 'k';
		
	    var html = '<g>' , h = 0 , text = '';
		for(var i= 0;i <=  this.ynum ; i++){
		    h = this.height - this.ysheight - i *this.yheight + 5;
			text = i*this.bv;
			if(label)text = (text / 1000) + label;
		    html += ('<text x="'+(this.xswidth - 5)+'" y="'+h+'" text-anchor="end" style="width:'+this.xswidth*0.1+'rem;color:#999;cursor:default;font-size:1.1rem;fill:#999;" opacity="1">'+text+'</text>');
		}
		
		html += '</g>';
		return html;
	}
	
	this.getLine = function(data , color){
	    var html = '<g>' , x = xe = y = ye = 0 , pots = [];
		for(var i = 0;i < this.xnum - 1;i++){
		    x = i * this.xwidth  + this.xswidth + this.xwidth / 2;
			y = this.height - this.ysheight - (data[i] / this.bv * this.yheight);
		    xe = (i+1) * this.xwidth  + this.xswidth + this.xwidth / 2;
			ye = this.height - this.ysheight - (data[i + 1] / this.bv * this.yheight);
			html += ('<line x1="'+x+'" y1="'+y+'" x2="'+xe+'" y2="'+ye+'" style="stroke:'+color+';stroke-width:1"/>');
		}

		html += '</g>';
		return html;
	}
	
	this.getPot = function(data , color){
	    var html = '<g>' , x = y = 0;
		
		for(var i = 0;i < this.xnum;i++){
		    x = i * this.xwidth  + this.xswidth + this.xwidth / 2;
			y = this.height - this.ysheight - (data[i] / this.bv * this.yheight);
		    html += ('<circle cx="'+x+'" cy="'+y+'" r="4"    fill="'+color+'"/>');
		}
		
		html += '</g>';
		return html;
	}
	
	this.getalias = function(){
	    var html = '<g>' , x = y = 0;
		x = this.width - this.pwidth - 100;
		y = this.ysheight / 2;
		html += '<line x1="'+x+'" y1="'+y+'" x2="'+(x + 20)+'" y2="'+y+'" style="stroke:#31c690;stroke-width:1"/>\
		         <circle cx="'+(x + 10)+'" cy="'+y+'" r="3"    fill="#31c690"/>\
				 <text x="'+(x + 22)+'" y="'+(y + 5)+'" text-anchor="begin" style="color:#999;font-size:1.1rem;fill:#999;" opacity="1">'+opt.alias[0]+'</text>';
		x += 55
		html += '<line x1="'+x+'" y1="'+y+'" x2="'+(x + 20)+'" y2="'+y+'" style="stroke:red;stroke-width:1"/>\
		         <circle cx="'+(x + 10)+'" cy="'+y+'" r="3"    fill="red"/>\
				 <text x="'+(x + 22)+'" y="'+(y + 5)+'" text-anchor="begin" style="color:#999;font-size:1.1rem;fill:#999;" opacity="1">'+opt.alias[1]+'</text>';
		
		
		html += '</g>';
		
		return html;
	}
	
	this.init();
};