/**
 * 表单插件
 * function :
 * 1. app.form.get(t , all) 获取单项输入项值或所有输入值
 * 2. app.form.check(t , all) 检测单项或全部输入
 * 3. app.form.getError() 获取错误描述
 * 4. app.form.regFunc(alias , fun) 注册新的检测方法
 * 5. app.form.getFuncname() 获取当前检测类型
 */
var app = app || {};
(function(app){
    app.form = new (function(app){
	    var me = this;
		
	    /**
		 * 获取单项输入项值或所有输入值
		 */
	    this.get = function(t , all){
		    if(!!all){
			    var param = {} , v = false , items = t.find("[name]");
				for(var i =0;i < items.length;i++){
				    v = this.get(items.eq(i));
					if(v === false)return false;
					param[items.eq(i).attr('name')] = v;
				}
				return param;
			}
		    var tags = ['INPUT' , 'SELECT' , 'TEXTAREA'];
			var tag = t.get(0).tagName.toUpperCase();
			var v = false;

			if($.inArray(tag , tags) < 0){
				var intype = t.attr('intype');
				if(intype == 'select'){
					v = t.find("input[type=text]").val();
				}else if(intype == 'checkbox'){
				    v = [];
				    t.find("input[type=checkbox]:checked").each(function(){
						v.push($(this).val());
				    });
				}else if(intype == 'gcheckbox'){//模拟
					v = [];
					t.find(".checkbox.checked").each(function(){
					    v.push($(this).attr('value'));
					});
				}else{
					v = $.trim(t.val());
				}
			}else{
				if(tag == 'SELECT'){
					 v = t.val();
					 return v == '0' ? 0 : v;
				}
				if(tag == 'INPUT'){
					var type = t.attr('type');
					if(type=="checkbox" || type=="radio"){
						var name = t.attr("name");
						if(type == 'checkbox'){
							v = [];
							$.each(t.parent().parent().find("[name="+name+"]:checked") , function(){
								v.push($(this).val());
							});
						}else{
							v = t.parent().parent().find("[name="+name+"]:checked");
							v = v.length == 0 ? false : v.val();
						}
						return v;
					}
				}
				v = $.trim(t.val());
			}
			 
			var tipc = t.attr('tipc')
			if(typeof tipc != 'undefined')if(v == tipc)v = '';
				 
			var fixedLen = t.attr('toFloat') , isInt = t.attr('toInt');
			if(typeof fixedLen != 'undefined' && fixedLen!=null){
				v = parseFloat(v);
				if(isNaN(v))v = 0;
				v = app.util.toFixed(v , parseInt(fixedLen));
			}
			if(!!isInt){
				v = parseInt(v);
				if(isNaN(v))v = 0;
			}
			return v;
		};
		
		/**
		 * 检测输入项值
		 */
		this.check = function(t , all){
		    if(!!all){//检测所有输入项
			    var items =  t.find("[valid]");
				for(var i=0;i< items.length;i++){
				    if(this.check(items.eq(i)) == false){
					    return false;
				    }
				}
				return true;
			}
			
		    var valid = t.attr('valid');
			if(!valid)return true;
			
			var value = this.get(t),
			    vs  =  valid.split("|"),
				_regExp = /(.*?)\[(.*?)\]/,
				matchs = [],
				fun = null,
				parme = null;
			for(var i in vs){
				matchs = vs[i].match(_regExp);
				if(matchs && matchs.length){
					fun = matchs[1];
					param = matchs[2];
				}else{
					fun = vs[i];
					param = null; 
				}
                
				this.error = '';
				this.funcname = fun;
				if(this.func[fun](value , param) == false){
				    var tip = t.attr(fun + '_tip');
				    if(typeof tip == 'undefined' || tip == null){
					    var label = t.attr('label') || '';
					    tip = label + this.tips[fun] + this.error;
					}
				    this.error = tip;
				    return false;	
				}
			}
			return true;
		};
		
		/**
		 * 获取当前检测类型
		 */
		this.getFuncname = function(){
		    return this.funcname;
		};
		
		/**
		 * 获取错误描述
		 */
		this.getError = function(){
		    return this.error;
		};
		
		/**
		 * 注册新的检测方法
		 */
		this.regFunc = function(alias , fun){
		    this.func[alias] = fun;
		};
		
		/**
		 * 检测方法
		 */
		this.func = {
		    required:function(value){//判断是否为空
				return typeof value == "object" ?  (value.length ? true : false) : (!value ? false : true);
			},
			minNum : function(value , param){//不能小于指定数
				param = parseFloat(param);
				value = parseFloat(value);
				if(isNaN(value)){
					me.error = '输入无效字符';
					value = 0;
				}
				if(value == 0 || value < param){
				    me.error =  value;
				}
				return value == 0 || value < param ? false : true; 
			},
			maxNum : function(value , param){//不能大于指定数
				param = parseFloat(param);
				value = parseFloat(value);
				if(isNaN(value)){
					me.error = '输入无效字符';
					value = 0;
				}
				if(value > param){
				    me.error =  param;
				}
				return value > param ? false : true; 
			},
			numeric:function(value)//判断是否是数字
			{
				return isNaN(value) ? false : true;
			},
			minLength : function(value , param){//判断字符串是否小于特定长度
				var len = parseInt(param),
					leng = value.length;
				if(leng < len){
					me.error = len + '，现有字符'+ leng;
					return false;
				}else{
					return true;
				}
			},
			maxLength:function (value , param){//判断字符串是否超过最大长度
				var len = parseInt(param),
				leng = value.length;
				if(leng > len){
					me.error = len + '，现有字符'+ leng;
					return false;
				}else{
					return true;
				}
			},
			/*是否相同*/
			repeat:function(value , param){
				return value == $("[name="+param+"]").val() ? true : false;
			},
			/*日期格式*/
			validDate:function(){
			},
			validEmail:function(value , param){
				if(value.length == 0)return true;
				var myreg = /^([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+@([a-zA-Z0-9]+[_|\_|\.]?)*[a-zA-Z0-9]+\.[a-zA-Z]{2,3}$/;
				return myreg.test(value) ? true : false;
			},
			validPhone : function(value , param){
				if(value.length != 11)return false;
				var reg = /^(13+\d{9})|(159+\d{8})|(153+\d{8})|(156+\d{8})|(18+\d{9})$/;
				return reg.test(value) ? true : false;
			},
			/*身份证验证*/
			isCardID : function(sId , param){
				if(sId.length == 0)return true;
				var iSum = 0 ;
				var info = "" ;
				var aCity={11:"北京",12:"天津",13:"河北",14:"山西",15:"内蒙古",21:"辽宁",22:"吉林",23:"黑龙江",31:"上海",32:"江苏",33:"浙江",34:"安徽",35:"福建",36:"江西",37:"山东",41:"河南",42:"湖北",43:"湖南",44:"广东",45:"广西",46:"海南",50:"重庆",51:"四川",52:"贵州",53:"云南",54:"西藏",61:"陕西",62:"甘肃",63:"青海",64:"宁夏",65:"新疆",71:"台湾",81:"香港",82:"澳门",91:"国外"} ;
				if(!/^\d{17}(\d|x)$/i.test(sId)){
				   me.error = "身份证长度或格式错误";
				   return false;
				}
				
				sId=sId.replace(/x$/i,"a");
				if(aCity[parseInt(sId.substr(0,2))]==null){
				   me.error = "身份证地区非法";
				   return false;
				}
				sBirthday=sId.substr(6,4)+"-"+Number(sId.substr(10,2))+"-"+Number(sId.substr(12,2));
				var d=new Date(sBirthday.replace(/-/g,"/")) ;
				if(sBirthday!=(d.getFullYear()+"-"+ (d.getMonth()+1) + "-" + d.getDate())){
				   me.error = "身份证上的出生日期非法";
				   return false;
				}
				for(var i = 17;i>=0;i --) iSum += (Math.pow(2,i) % 11) * parseInt(sId.charAt(17 - i),11) ;
				if(iSum%11!=1){
				   me.error = "身份证号非法";
				   return false;
				}
				return true;
		    }
		};
		
		/**
		 * 提示语定义
		 */
		this.tips = {
			required : 	 '不能为空',
			  minNum :   '不能小于',
			  maxNum :   '不能大于',
			minLength:	 '字符长度不能小于',
			maxLength:   '字符长度不能大于',
			alpha:       '只能由字母组成',
			alphaNumeric:'只能由字母和数字组成',
			alphaDash:   '只能由字母，数字及下划线组成',
			numeric:     '只能由数字组成',
			validEmail:  'Email格式不正确',
			validIp:     'IP地址无效',
			validPhone : '手机号码输入错误',
			validDate:   '格式不正确',
			repeat:      '两次输入不一致',
			isCardID :   ''
		};
	})(app);
})(app);